From 05150461ca543e3eff7f869a24f4813e47bd4d8c Mon Sep 17 00:00:00 2001
From: liuyg <376836862@qq.com>
Date: Tue, 03 Aug 2021 14:59:50 +0800
Subject: [PATCH] Merge branch 'master' of http://192.168.0.105:10010/r/zhba_enterprises

---
 src/router/views/index.js |  142 ++++++++++++++++++++++++++++------------------
 1 files changed, 86 insertions(+), 56 deletions(-)

diff --git a/src/router/views/index.js b/src/router/views/index.js
index b031e53..390b2eb 100644
--- a/src/router/views/index.js
+++ b/src/router/views/index.js
@@ -661,59 +661,89 @@
                 import ( /* webpackChunkName: "views" */ '@/views/trainExam/index')
         }]
     },
-  {
-    path: '/applyexam',
-    redirect: '/applyexam/index',
-    component: Layout,
-    children: [{
-      path: 'index',
-      name: '报名考试',
-      meta: {
-        i18n: 'index',
-      },
-      component: () =>
-        import( /* webpackChunkName: "views" */ '@/views/applyexam/index')
-    }]
-  },
-  {
-    path: '/startexam',
-    redirect: '/startexam/index',
-    component: Layout,
-    children: [{
-      path: 'index',
-      name: '开始考试',
-      meta: {
-        i18n: 'index',
-      },
-      component: () =>
-        import( /* webpackChunkName: "views" */ '@/views/startexam/index')
-    }]
-  },
-  {
-    path: '/titleDetails',
-    component: () =>
-      import( /* webpackChunkName: "views" */ '@/views/exam/topicDetails')
-  },
-  {
-    path: '',
-    component: Layout,
-    children: [{
-      path: '/exam/subjects/:id',
-      component: () => import('@/views/exam/examSubjects'),
-      name: '题目管理',
-      title: '题目管理',
-      noCache: true
-    }]
-  },
-  {
-    path: '',
-    component: Layout,
-    children: [{
-      path: '/startexam/:id',
-      component: () => import('@/views/startexam/index'),
-      name: '开始考试',
-      title: '开始考试',
-      noCache: true
-    }]
-  },
-]
+    {
+        path: '/applyexam',
+        redirect: '/applyexam/index',
+        component: Layout,
+        children: [{
+            path: 'index',
+            name: '报名考试',
+            meta: {
+                i18n: 'index',
+            },
+            component: () =>
+                import ( /* webpackChunkName: "views" */ '@/views/applyexam/index')
+        }]
+    },
+    {
+        path: '/applydetailed',
+        redirect: '/applydetailed/index',
+        component: Layout,
+        children: [{
+            path: 'index',
+            name: '报名清册',
+            meta: {
+                i18n: 'index',
+            },
+            component: () =>
+                import ( /* webpackChunkName: "views" */ '@/views/applydetailed/index')
+        }]
+    },
+    {
+        path: '/trainApply',
+        redirect: '/trainApply/index',
+        component: Layout,
+        children: [{
+            path: 'index',
+            name: '报名清册',
+            meta: {
+                i18n: 'index',
+            },
+            component: () =>
+                import ( /* webpackChunkName: "views" */ '@/views/trainApply/index')
+        }]
+    },
+    {
+        path: '/startexam',
+        redirect: '/startexam/index',
+        component: Layout,
+        children: [{
+            path: 'index',
+            name: '开始考试',
+            meta: {
+                i18n: 'index',
+            },
+            component: () =>
+                import ( /* webpackChunkName: "views" */ '@/views/startexam/index')
+        }]
+    },
+    {
+        path: '/titleDetails',
+        component: () =>
+            import ( /* webpackChunkName: "views" */ '@/views/exam/topicDetails')
+    },
+    {
+        path: '',
+        component: Layout,
+        children: [{
+            path: '/exam/subjects/:id',
+            component: () =>
+                import ('@/views/exam/examSubjects'),
+            name: '题目管理',
+            title: '题目管理',
+            noCache: true
+        }]
+    },
+    {
+        path: '',
+        component: Layout,
+        children: [{
+            path: '/startexam/:id',
+            component: () =>
+                import ('@/views/startexam/index'),
+            name: '开始考试',
+            title: '开始考试',
+            noCache: true
+        }]
+    },
+]
\ No newline at end of file

--
Gitblit v1.9.3